@@ -1,9 +1,10 @@
 use std::path::PathBuf;
-use clap::{Command, Arg};
+use clap::{Command, Arg, ArgMatches};
 
 use sphinx::frontend;
 use sphinx::{BuildErrors, build_module};
 use sphinx::source::ModuleSource;
+use sphinx::runtime::strings::StringInterner;
 use sphinx::debug::symbol::DebugSymbolResolver;
 use sphinx::debug::dasm::Disassembler;
 
@@ -20,6 +21,11 @@ fn main() {
             .help("path to a source file to disassemble")
             .value_name("FILE")
         )
+        .arg(
+            Arg::new("parse_only")
+            .short('P')
+            .help("Parse and print AST instead of dissassembly")
+        )
         .arg(
             Arg::new("bytecode")
             .short('d')
@@ -53,6 +59,12 @@ fn main() {
     }
     
     println!("\nSphinx Version {}\n", version);
+
+    if args.is_present("parse_only") {
+        parse_and_print_ast(&args, name, &source);
+        return;
+    }
+    
     
     // build module
     let build_result = build_module(&source);
@@ -92,4 +104,26 @@ fn main() {
     
     println!("== \"{}\" ==", name);
     println!("{}", dasm);
+}
+
+fn parse_and_print_ast(_args: &ArgMatches, name: &str, source: &ModuleSource) {
+    let source_text = match source.read_text() {
+        Ok(source_text) => source_text,
+        
+        Err(error) => {
+            println!("Error reading source: {}.", error);
+            return;
+        },
+    };
+    
+    let mut interner = StringInterner::new();
+    let parse_result = sphinx::parse_source(&mut interner, source_text);
+    
+    match parse_result {
+        Err(errors) => {
+            println!("Errors in file \"{}\":\n", name);
+            frontend::print_source_errors(source, &errors);
+        },
+        Ok(ast) => println!("{:#?}", ast),
+    }
 }
\ No newline at end of file
