@@ -1,15 +1,15 @@
 use crate::runtime::Gc;
-use crate::runtime::module::GlobalEnv;
+use crate::runtime::module::NamespaceEnv;
 
 
-pub fn create_misc_builtins(env: Gc<GlobalEnv>) {
+pub fn create_misc_builtins(env: Gc<NamespaceEnv>) {
     
     let to_str = native_function!(str, env, params(value) => {
         Ok(Variant::from(value.fmt_str()?))
     });
     
-    let echo = native_function!(echo, env, params(value) => {
-        Ok(Variant::from(value.fmt_echo()?))
+    let repr = native_function!(repr, env, params(value) => {
+        Ok(Variant::from(value.fmt_repr()?))
     });
     
     let print = native_function!(print, env, variadic(values) => {
@@ -40,7 +40,7 @@ pub fn create_misc_builtins(env: Gc<GlobalEnv>) {
     namespace_insert!(env.borrow_mut(), {
         fun _ = globals;
         fun _ = to_str;
-        fun _ = echo;
+        fun _ = repr;
         fun _ = print;
     });
 }
