@@ -17,7 +17,7 @@ pub mod parser;
 pub mod language;
 pub mod codegen;
 pub mod runtime;
-pub mod stdlib;
+pub mod builtins;
 
 pub mod frontend;
 pub mod debug;
