@@ -3,7 +3,6 @@ use ahash::{self, AHasher};
 
 mod variant;
 pub mod strings;
-pub mod ops;
 pub mod types;
 pub mod gc;
 pub mod vm;
@@ -13,7 +12,7 @@ pub mod errors;
 
 mod tests;
 
-pub use gc::GC;
+pub use gc::Gc;
 pub use vm::VirtualMachine;
 pub use strings::STRING_TABLE;
 pub use variant::{Variant, VariantKey};
