@@ -2,7 +2,7 @@ use core::fmt;
 use core::cell::Cell;
 use crate::codegen::{FunctionID, FunctionProto};
 use crate::runtime::Variant;
-use crate::runtime::module::{Module, GlobalEnv};
+use crate::runtime::module::{Module, NamespaceEnv};
 use crate::runtime::vm::VirtualMachine;
 use crate::runtime::gc::{Gc, GcTrace};
 use crate::runtime::errors::ExecResult;
@@ -19,7 +19,7 @@ pub enum Call {
     Chunk {
         module: Gc<Module>,
         chunk_id: FunctionID,
-        fixed_nargs: usize,
+        nparams: usize,
     },
     Native {
         func: Gc<NativeFunction>,
@@ -61,14 +61,6 @@ impl Function {
     pub fn signature(&self) -> &Signature {
         self.proto().signature()
     }
-    
-    fn fixed_args_count(&self) -> usize {
-        let signature = self.signature();
-        
-        signature.required().len()
-        + signature.default().len()
-        + if signature.variadic().is_some() { 1 } else { 0 }
-    }
 }
 
 impl Callable for Function {
@@ -78,7 +70,7 @@ impl Callable for Function {
         Call::Chunk {
             module: self.module,
             chunk_id: self.fun_id,
-            fixed_nargs: self.fixed_args_count(),
+            nparams: self.signature().param_count(),
         }
     }
 }
@@ -153,18 +145,18 @@ pub type NativeFn = fn(self_fun: &NativeFunction, vm: &mut VirtualMachine<'_>, a
 pub struct NativeFunction {
     signature: Signature,
     defaults: Option<Box<[Variant]>>,
-    env: Gc<GlobalEnv>,
+    env: Gc<NamespaceEnv>,
     func: NativeFn,
 }
 
 impl NativeFunction {
-    pub fn new(signature: Signature, defaults: Option<Box<[Variant]>>, env: Gc<GlobalEnv>, func: NativeFn) -> Self {
+    pub fn new(signature: Signature, defaults: Option<Box<[Variant]>>, env: Gc<NamespaceEnv>, func: NativeFn) -> Self {
         Self { signature, defaults, env, func }
     }
     
     pub fn signature(&self) -> &Signature { &self.signature }
     
-    pub fn env(&self) -> Gc<GlobalEnv> { self.env }
+    pub fn env(&self) -> Gc<NamespaceEnv> { self.env }
     
     pub fn defaults(&self) -> &[Variant] {
         match self.defaults.as_ref() {
