@@ -47,7 +47,7 @@ impl MetaObject for StringValue {
         None
     }
     
-    fn fmt_echo(&self) -> ExecResult<StringValue> {
+    fn fmt_repr(&self) -> ExecResult<StringValue> {
         let mut buf = StrBuffer::<64>::new();
         if write!(buf, "\"{}\"", self).is_ok() {
             Ok(StringValue::new_uninterned(buf))
